//////////////////////////////////////////////////////////////////////////// 
// IPD - Image Processing Design Toolbox
//
// Copyright (c) by Dr. Eng. (J) Harald Galda, 2009 - 2010
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
////////////////////////////////////////////////////////////////////////////


#include "IPD.h"
#include "LinearFilter.h"
#include "TransferImageData.h"


template<class TSource, class TDestination>
void FilterWithMask(const TSource* const Source,
                    TUInt NumberOfImageColumns,
                    TUInt NumberOfImageRows,
                    const TSource* const Mask,
                    TUInt NumberOfMaskColumns, 
                    TUInt NumberOfMaskRows,
                    TDestination** Destination)
{
 // Initializations

 *Destination = NULL;

 TUInt NumberOfPixels = NumberOfImageColumns * NumberOfImageRows;

 // Memory for the filtered image is allocated.

 TSource* FilteredImage = new TSource[NumberOfPixels];

 if(FilteredImage == NULL)
 {
  Scierror(ERROR_MEMORY, "Internal error occured.");

  return;
 } // if

 // Filter is initialized.
 CLinearFilter<TSource> Filter(NumberOfMaskColumns, NumberOfMaskRows, Mask);

 // Filter is applied.
 Filter.FilterImage(NumberOfImageColumns, NumberOfImageRows, Source, FilteredImage);

 // Each gray value is mapped to its absolute value.
   
 for(TUInt n = 0; n < NumberOfPixels; n++)
 {
  FilteredImage[n] = abs(FilteredImage[n]);
 } // for

 // ResultImage is set.

 TDestination* DestinationImage = NULL;

 TransferImageData(NumberOfPixels, FilteredImage, &DestinationImage);

 delete FilteredImage;

 if(DestinationImage == NULL)
 {
  Scierror(ERROR_MEMORY, "Internal error occured.");

  return;
 } // if

 *Destination = DestinationImage;
} // FilterWithMask