//////////////////////////////////////////////////////////////////////////// 
// IPD - Image Processing Design Toolbox
//
// Copyright (c) by Dr. Eng. (J) Harald Galda, 2009 - 2010
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
////////////////////////////////////////////////////////////////////////////


#ifndef MEDIAN_H
#define MEDIAN_H


#include "Filter.h"


template<class GrayValueType>
class CMedian : public CFilter<GrayValueType>
{
 public:

  CMedian(TUInt NumberOfColumns, TUInt NumberOfRows);

  virtual ~CMedian(void){};

 protected:

  typedef list<GrayValueType> TSortableGrayValueList;

  virtual GrayValueType ComputeGrayValue(const TGrayValueList& GrayValues);

  const bool m_IsOdd;

  const TUInt m_CentralElement;
};


template<class GrayValueType>
CMedian<GrayValueType>::CMedian(TUInt NumberOfColumns, TUInt NumberOfRows):
CFilter(NumberOfColumns, NumberOfRows),
m_IsOdd((NumberOfColumns * NumberOfRows) % 2 > 0),
m_CentralElement((NumberOfColumns * NumberOfRows) / 2)
{
 ComputeOffsets(NumberOfRows, NumberOfColumns);
} // CMedian::CMedian


template<class GrayValueType>
GrayValueType CMedian<GrayValueType>::ComputeGrayValue(const TGrayValueList& GrayValues)
{
 TSortableGrayValueList SortedList;

 for(TUInt n = 0; n < m_NumberOfElements; n++)
 {
  SortedList.push_back(GrayValues[n]);
 } // for

 SortedList.sort();

 TGrayValueList SortedGrayValues;

 TSortableGrayValueList::iterator ListIndex;

 for(ListIndex = SortedList.begin(); ListIndex != SortedList.end(); ListIndex++)
 {
  SortedGrayValues.push_back(*ListIndex);
 } // for

 if(m_IsOdd)
 {
  return SortedGrayValues[m_CentralElement];
 }
 else
 {
  return (SortedGrayValues[m_CentralElement] + SortedGrayValues[m_CentralElement]) / 2;
 } // if
} // CMedian::ComputeGrayValue


#endif


